test_that("exported functions exist and are functions", {
  expect_true(is.function(RMUreliability))
  expect_true(is.function(dif_statistic))
  expect_true(is.function(fit_statistic_pcm))
  expect_true(is.function(fit_statistic_rm))
  expect_true(is.function(infit_post))
  expect_true(is.function(infit_statistic))
  expect_true(is.function(item_parameters))
  expect_true(is.function(item_restscore_post))
  expect_true(is.function(item_restscore_statistic))
  expect_true(is.function(person_parameters))
  expect_true(is.function(plot_bars))
  expect_true(is.function(plot_icc))
  expect_true(is.function(plot_ipf))
  expect_true(is.function(plot_residual_pca))
  expect_true(is.function(plot_stackedbars))
  expect_true(is.function(plot_targeting))
  expect_true(is.function(plot_tile))
  expect_true(is.function(posterior_to_prior))
  expect_true(is.function(q3_post))
  expect_true(is.function(q3_statistic))
})
